@@ -32,9 +32,9 @@ public:
                                      const QVariantList &args = QVariantList());
 
 public Q_SLOTS:
-    void save() Q_DECL_OVERRIDE;
-    void load() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void save() override;
+    void load() override;
+    void defaults() override;
 
 private:
     QCheckBox *mQueryCompletionCheckBox;
